@@ -1,5 +1,5 @@
 package Whelk::Schema::Definition::Number;
-$Whelk::Schema::Definition::Number::VERSION = '1.03';
+$Whelk::Schema::Definition::Number::VERSION = '1.04';
 use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
 use Scalar::Util qw(looks_like_number);
 
@@ -7,22 +7,8 @@ sub openapi_dump
 {
 	my ($self, $openapi_obj, %hints) = @_;
 
-	my $res = {
-		%{$self->_openapi_dump_extra_rules},
-		type => 'number',
-	};
-
-	if (defined $self->description) {
-		$res->{description} = $self->description;
-	}
-
-	if ($self->has_default) {
-		$res->{default} = $self->inhale_exhale;
-	}
-
-	if (defined $self->example) {
-		$res->{example} = $self->inhale_exhale($self->example);
-	}
+	my $res = $self->SUPER::openapi_dump($openapi_obj, %hints);
+	$res->{type} = 'number';
 
 	return $res;
 }
