@@ -1,5 +1,5 @@
 package Whelk::Schema::Definition::Object;
-$Whelk::Schema::Definition::Object::VERSION = '1.03';
+$Whelk::Schema::Definition::Object::VERSION = '1.04';
 use Whelk::StrictBase 'Whelk::Schema::Definition';
 
 attr '?properties' => undef;
@@ -13,10 +13,8 @@ sub openapi_dump
 		return $self->_dump_parameters($openapi_obj, %hints);
 	}
 
-	my $res = {
-		%{$self->_openapi_dump_extra_rules},
-		type => 'object',
-	};
+	my $res = $self->SUPER::openapi_dump($openapi_obj, %hints);
+	$res->{type} = 'object';
 
 	my @required;
 	my %items;
@@ -33,10 +31,6 @@ sub openapi_dump
 			if @required;
 	}
 
-	if (defined $self->description) {
-		$res->{description} = $self->description;
-	}
-
 	return $res;
 }
 
