@@ -1,27 +1,13 @@
 package Whelk::Schema::Definition::String;
-$Whelk::Schema::Definition::String::VERSION = '1.03';
+$Whelk::Schema::Definition::String::VERSION = '1.04';
 use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
 
 sub openapi_dump
 {
 	my ($self, $openapi_obj, %hints) = @_;
 
-	my $res = {
-		%{$self->_openapi_dump_extra_rules},
-		type => 'string',
-	};
-
-	if (defined $self->description) {
-		$res->{description} = $self->description;
-	}
-
-	if ($self->has_default) {
-		$res->{default} = $self->inhale_exhale;
-	}
-
-	if (defined $self->example) {
-		$res->{example} = $self->inhale_exhale($self->example);
-	}
+	my $res = $self->SUPER::openapi_dump($openapi_obj, %hints);
+	$res->{type} = 'string';
 
 	return $res;
 }
